@@ -1,3 +1,5 @@
+#
+#
 Jupytils_debug=0;
 
 def log(*args, debug=False, end=' ', **kwargs):
@@ -20,8 +22,5 @@ for m in sys.modules:
 
 #print("Modules loaded: ", dels)
 
-try:
-    from Jupytils.jcommon import *
-    LoadJupytils()
-except:
-    pass
+from Jupytils.jcommon import *
+LoadJupytils()
